<?php

namespace backend\controllers;

use common\models\Fields;
use Yii;
use yii\filters\AccessControl;
use backend\models\Articles;
use backend\models\ArticlesSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\imagine\Image;
use yii\web\UploadedFile;

/**
 * ArticlesController implements the CRUD actions for Articles model.
 */
class ArticlesController extends Controller
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['logout', 'index','create','update','view','delete','test-img' ],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }
    /**
     * Lists all Articles models.
     * @return mixed
     */
    public function actionIndex($type)
    {
        $searchModel = new ArticlesSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams,$type);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'type' => $type
        ]);
    }

    /**
     * Displays a single Articles model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Articles model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate($type)
    {
        $model = new Articles();

        if (  $model->load(Yii::$app->request->post())) {
            $model->date = date('Y/m/d');
            $model->type = $type;
            $model->save();
            $fields = Yii::$app->request->post('Fields');
            Fields::deleteAll(['table_id'=> $model->id, 'table_name'=>'Articles']);
            if($fields){

                foreach($fields as $k => $field){
                    foreach($field as $row){

                        $field_model = new Fields();
                        $field_model->field_name =  isset($row['description']) ? $row['description'] : '';
                        $field_model->value =  isset($row['value']) ? $row['value'] : '';
                        $field_model->table_name =  'Articles';
                        $field_model->table_id   = $model->id;
                        $field_model->field_type =  $k;
                        $field_model->save();
                    }

                }
            }
            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('create', [
                'model' => $model,

            ]);
        }
    }

    /**
     * Updates an existing Articles model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $model->load(Yii::$app->request->post());
        $model->date = date('Y/m/d');
        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            $fields = Yii::$app->request->post('Fields');
            Fields::deleteAll(['table_id'=> $model->id, 'table_name'=>'Articles']);
            if($fields){

                foreach($fields as $k => $field){
                    foreach($field as $row){

                        $field_model = new Fields();
                        $field_model->field_name =  isset($row['description']) ? $row['description'] : '';
                        $field_model->value =  isset($row['value']) ? $row['value'] : '';
                        $field_model->table_name =  'Articles';
                        $field_model->table_id   = $model->id;
                        $field_model->field_type =  $k;
                        $field_model->save();
                    }

                }
            }
            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Articles model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Articles model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Articles the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Articles::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
