<?php

namespace backend\controllers;

use common\models\Fields;
use Yii;
use yii\filters\AccessControl;
use common\models\Gallery;
use common\models\GallerySearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * GalleryController implements the CRUD actions for Gallery model.
 */
class GalleryController extends Controller
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['logout', 'index','create','update','view','delete','test-img' ],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * Lists all Gallery models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new GallerySearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Gallery model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Gallery model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Gallery();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            $model->date = date('Y/m/d');
            $model->save();
            $fields = Yii::$app->request->post('Fields');
            Fields::deleteAll(['table_id'=> $model->id, 'table_name'=>'Gallery']);
            if($fields){

                foreach($fields as $k => $field){
                    foreach($field as $row){

                        $field_model = new Fields();
                        $field_model->field_name =  isset($row['description']) ? $row['description'] : '';
                        $field_model->value =  isset($row['value']) ? $row['value'] : '';
                        $field_model->table_name =  'Gallery';
                        $field_model->table_id   = $model->id;
                        $field_model->field_type =  $k;
                        $field_model->save();
                    }

                }
            }
            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('create', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Gallery model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            $model->date = date('Y/m/d');
            $model->save();
            $fields = Yii::$app->request->post('Fields');
            Fields::deleteAll(['table_id'=> $model->id, 'table_name'=>'Gallery']);
            if($fields){

                foreach($fields as $k => $field){
                    foreach($field as $row){

                        $field_model = new Fields();
                        $field_model->field_name =  isset($row['description']) ? $row['description'] : '';
                        $field_model->value =  isset($row['value']) ? $row['value'] : '';
                        $field_model->table_name =  'Gallery';
                        $field_model->table_id   = $model->id;
                        $field_model->field_type =  $k;
                        $field_model->save();
                    }

                }
            }
            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Gallery model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Gallery model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Gallery the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Gallery::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
